.. Avlos documentation master file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Avlos documentation!
========================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   introduction
   spec_format
   config
   cli


